@@ -16,8 +16,16 @@ class ArgumentsMixin:
     ARGUMENTS_PARSER = FlaskParser()
 
     def arguments(
-            self, schema, *, location='json', content_type=None, required=True,
-            description=None, example=None, examples=None, **kwargs
+        self,
+        schema,
+        *,
+        location="json",
+        content_type=None,
+        required=True,
+        description=None,
+        example=None,
+        examples=None,
+        **kwargs
     ):
         """Decorator specifying the schema used to deserialize parameters
 
@@ -52,96 +60,90 @@ class ArgumentsMixin:
         # At this stage, put schema instance in doc dictionary. Il will be
         # replaced later on by $ref or json.
         parameters = {
-            'in': location,
-            'required': required,
-            'schema': schema,
+            "in": location,
+            "required": required,
+            "schema": schema,
         }
         if content_type is not None:
-            parameters['content_type'] = content_type
+            parameters["content_type"] = content_type
         if example is not None:
-            parameters['example'] = example
+            parameters["example"] = example
         if examples is not None:
-            parameters['examples'] = examples
+            parameters["examples"] = examples
         if description is not None:
-            parameters['description'] = description
+            parameters["description"] = description
 
         error_status_code = kwargs.get(
-            'error_status_code',
-            self.ARGUMENTS_PARSER.DEFAULT_VALIDATION_STATUS
+            "error_status_code", self.ARGUMENTS_PARSER.DEFAULT_VALIDATION_STATUS
         )
 
         def decorator(func):
-
             @wraps(func)
             def wrapper(*f_args, **f_kwargs):
                 return func(*f_args, **f_kwargs)
 
             # Add parameter to parameters list in doc info in function object
             # The deepcopy avoids modifying the wrapped function doc
-            wrapper._apidoc = deepcopy(getattr(wrapper, '_apidoc', {}))
-            docs = wrapper._apidoc.setdefault('arguments', {})
-            docs.setdefault('parameters', []).append(parameters)
-            docs.setdefault('responses', {})[
+            wrapper._apidoc = deepcopy(getattr(wrapper, "_apidoc", {}))
+            docs = wrapper._apidoc.setdefault("arguments", {})
+            docs.setdefault("parameters", []).append(parameters)
+            docs.setdefault("responses", {})[error_status_code] = http.HTTPStatus(
                 error_status_code
-            ] = http.HTTPStatus(error_status_code).name
+            ).name
 
             # Call use_args (from webargs) to inject params in function
-            return self.ARGUMENTS_PARSER.use_args(
-                schema, location=location, **kwargs)(wrapper)
+            return self.ARGUMENTS_PARSER.use_args(schema, location=location, **kwargs)(
+                wrapper
+            )
 
         return decorator
 
     def _prepare_arguments_doc(self, doc, doc_info, *, spec, **kwargs):
         # This callback should run first as it overrides existing parameters
         # in doc. Following callbacks should append to parameters list.
-        operation = doc_info.get('arguments')
+        operation = doc_info.get("arguments")
         if operation:
             parameters = [
-                p for p in operation['parameters']
-                if isinstance(p, abc.Mapping)
+                p for p in operation["parameters"] if isinstance(p, abc.Mapping)
             ]
             # OAS 2
             if spec.openapi_version.major < 3:
                 for param in parameters:
-                    if param['in'] in (
-                            self.DEFAULT_LOCATION_CONTENT_TYPE_MAPPING
-                    ):
+                    if param["in"] in (self.DEFAULT_LOCATION_CONTENT_TYPE_MAPPING):
                         content_type = (
-                            param.pop('content_type', None) or
-                            self.DEFAULT_LOCATION_CONTENT_TYPE_MAPPING[
-                                param['in']]
+                            param.pop("content_type", None)
+                            or self.DEFAULT_LOCATION_CONTENT_TYPE_MAPPING[param["in"]]
                         )
                         if content_type != DEFAULT_REQUEST_BODY_CONTENT_TYPE:
-                            operation['consumes'] = [content_type, ]
+                            operation["consumes"] = [
+                                content_type,
+                            ]
                         # body and formData are mutually exclusive
                         break
             # OAS 3
             else:
                 for param in parameters:
-                    if param['in'] in (
-                            self.DEFAULT_LOCATION_CONTENT_TYPE_MAPPING
-                    ):
+                    if param["in"] in (self.DEFAULT_LOCATION_CONTENT_TYPE_MAPPING):
                         request_body = {
                             x: param[x]
-                            for x in ('description', 'required')
+                            for x in ("description", "required")
                             if x in param
                         }
                         fields = {
                             x: param.pop(x)
-                            for x in ('schema', 'example', 'examples')
+                            for x in ("schema", "example", "examples")
                             if x in param
                         }
                         content_type = (
-                            param.pop('content_type', None) or
-                            self.DEFAULT_LOCATION_CONTENT_TYPE_MAPPING[
-                                param['in']]
+                            param.pop("content_type", None)
+                            or self.DEFAULT_LOCATION_CONTENT_TYPE_MAPPING[param["in"]]
                         )
-                        request_body['content'] = {content_type: fields}
-                        operation['requestBody'] = request_body
+                        request_body["content"] = {content_type: fields}
+                        operation["requestBody"] = request_body
                         # There can be only one requestBody
-                        operation['parameters'].remove(param)
-                        if not operation['parameters']:
-                            del operation['parameters']
+                        operation["parameters"].remove(param)
+                        if not operation["parameters"]:
+                            del operation["parameters"]
                         break
             doc = deepupdate(doc, operation)
         return doc
