@@ -51,12 +51,12 @@ from .etag import EtagMixin
 
 
 class Blueprint(
-        FlaskBlueprint,
-        ArgumentsMixin, ResponseMixin, PaginationMixin, EtagMixin):
+    FlaskBlueprint, ArgumentsMixin, ResponseMixin, PaginationMixin, EtagMixin
+):
     """Blueprint that registers info in API documentation"""
 
     # Order in which the methods are presented in the spec
-    HTTP_METHODS = ['OPTIONS', 'HEAD', 'GET', 'POST', 'PUT', 'PATCH', 'DELETE']
+    HTTP_METHODS = ["OPTIONS", "HEAD", "GET", "POST", "PUT", "PATCH", "DELETE"]
 
     DEFAULT_LOCATION_CONTENT_TYPE_MAPPING = {
         "json": "application/json",
@@ -68,7 +68,7 @@ class Blueprint(
 
     def __init__(self, *args, **kwargs):
 
-        self.description = kwargs.pop('description', '')
+        self.description = kwargs.pop("description", "")
 
         super().__init__(*args, **kwargs)
 
@@ -129,7 +129,7 @@ class Blueprint(
         # - to avoid a name clash when registering a MehtodView
         # - to use it as a key internally in endpoint -> doc mapping
         if endpoint in self._endpoints:
-            endpoint = '{}_{}'.format(endpoint, len(self._endpoints))
+            endpoint = f"{endpoint}_{len(self._endpoints)}"
         self._endpoints.append(endpoint)
 
         if isinstance(view_func, MethodViewType):
@@ -139,23 +139,18 @@ class Blueprint(
 
         # Add URL rule in Flask and store endpoint documentation
         super().add_url_rule(rule, endpoint, func, **options)
-        self._store_endpoint_docs(
-            endpoint, view_func, parameters, tags, **options)
+        self._store_endpoint_docs(endpoint, view_func, parameters, tags, **options)
 
     def route(self, rule, *, parameters=None, tags=None, **options):
         """Decorator to register view function in application and documentation
 
         Calls :meth:`add_url_rule <Blueprint.add_url_rule>`.
         """
+
         def decorator(func):
             endpoint = options.pop("endpoint", None)
             self.add_url_rule(
-                rule,
-                endpoint,
-                func,
-                parameters=parameters,
-                tags=tags,
-                **options
+                rule, endpoint, func, parameters=parameters, tags=tags, **options
             )
             return func
 
@@ -171,10 +166,11 @@ class Blueprint(
             # Get documentation from decorators
             # Deepcopy doc info as it may be used for several methods and it
             # may be mutated in apispec
-            doc = deepcopy(getattr(function, '_apidoc', {}))
+            doc = deepcopy(getattr(function, "_apidoc", {}))
             # Get summary/description from docstring
-            doc['docstring'] = load_info_from_docstring(
-                function.__doc__, delimiter=self.DOCSTRING_INFO_DELIMITER)
+            doc["docstring"] = load_info_from_docstring(
+                function.__doc__, delimiter=self.DOCSTRING_INFO_DELIMITER
+            )
             # Tags for this resource
             doc["tags"] = tags
             # Store function doc infos for later processing/registration
@@ -184,20 +180,17 @@ class Blueprint(
         if isinstance(obj, MethodViewType):
             for method in self.HTTP_METHODS:
                 if method in obj.methods:
-                    if (
-                        "methods" not in options or
-                        method in options['methods']
-                    ):
+                    if "methods" not in options or method in options["methods"]:
                         func = getattr(obj, method.lower())
                         store_method_docs(method, func)
         # Function
         else:
             for method in self.HTTP_METHODS:
-                if method in options.get('methods', ('GET', )):
+                if method in options.get("methods", ("GET",)):
                     store_method_docs(method, obj)
 
         # Store parameters doc info from route decorator
-        endpoint_doc_info['parameters'] = parameters
+        endpoint_doc_info["parameters"] = parameters
 
     def register_views_in_doc(self, api, app, spec, *, name):
         """Register views information in documentation
@@ -214,11 +207,11 @@ class Blueprint(
         # Deepcopy to avoid mutating the source. Allows registering blueprint
         # multiple times (e.g. when creating multiple apps during tests).
         for endpoint, endpoint_doc_info in deepcopy(self._docs).items():
-            parameters = endpoint_doc_info.pop('parameters')
+            parameters = endpoint_doc_info.pop("parameters")
             doc = OrderedDict()
             # Use doc info stored by decorators to generate doc
             for method_l, operation_doc_info in endpoint_doc_info.items():
-                tags = operation_doc_info.pop('tags')
+                tags = operation_doc_info.pop("tags")
                 operation_doc = {}
                 for func in self._prepare_doc_cbks:
                     operation_doc = func(
@@ -227,17 +220,23 @@ class Blueprint(
                         api=api,
                         app=app,
                         spec=spec,
-                        method=method_l
+                        method=method_l,
                     )
-                operation_doc.update(operation_doc_info['docstring'])
+                operation_doc.update(operation_doc_info["docstring"])
                 # Tag all operations with Blueprint name unless tags specified
-                operation_doc['tags'] = tags if tags is not None else [name, ]
+                operation_doc["tags"] = (
+                    tags
+                    if tags is not None
+                    else [
+                        name,
+                    ]
+                )
                 # Complete doc with manual doc info
-                manual_doc = operation_doc_info.get('manual_doc', {})
+                manual_doc = operation_doc_info.get("manual_doc", {})
                 doc[method_l] = deepupdate(operation_doc, manual_doc)
 
             # Thanks to self.route, there can only be one rule per endpoint
-            full_endpoint = '.'.join((name, endpoint))
+            full_endpoint = ".".join((name, endpoint))
             rule = next(app.url_map.iter_rules(full_endpoint))
             spec.path(rule=rule, operations=doc, parameters=parameters)
 
@@ -255,16 +254,17 @@ class Blueprint(
                 def get(...):
                     ...
         """
-        def decorator(func):
 
+        def decorator(func):
             @wraps(func)
             def wrapper(*f_args, **f_kwargs):
                 return func(*f_args, **f_kwargs)
 
             # The deepcopy avoids modifying the wrapped function doc
-            wrapper._apidoc = deepcopy(getattr(wrapper, '_apidoc', {}))
-            wrapper._apidoc['manual_doc'] = deepupdate(
-                deepcopy(wrapper._apidoc.get('manual_doc', {})), kwargs)
+            wrapper._apidoc = deepcopy(getattr(wrapper, "_apidoc", {}))
+            wrapper._apidoc["manual_doc"] = deepupdate(
+                deepcopy(wrapper._apidoc.get("manual_doc", {})), kwargs
+            )
             return wrapper
 
         return decorator
