@@ -15,13 +15,14 @@ from flask_smorest import pagination as fs_pagination
 from .plugins import FlaskPlugin
 from .field_converters import uploadfield2properties
 from .constants import (
-    DEFAULT_REQUEST_BODY_CONTENT_TYPE, DEFAULT_RESPONSE_CONTENT_TYPE,
+    DEFAULT_REQUEST_BODY_CONTENT_TYPE,
+    DEFAULT_RESPONSE_CONTENT_TYPE,
 )
 
 
 def _add_leading_slash(string):
     """Add leading slash to a string if there is None"""
-    return string if string.startswith('/') else '/' + string
+    return string if string.startswith("/") else "/" + string
 
 
 class DocBlueprintMixin:
@@ -34,21 +35,21 @@ class DocBlueprintMixin:
         - json spec file
         - spec UI (ReDoc, Swagger UI).
         """
-        api_url = self._app.config.get('OPENAPI_URL_PREFIX', None)
+        api_url = self._app.config.get("OPENAPI_URL_PREFIX", None)
         if api_url is not None:
             blueprint = flask.Blueprint(
-                'api-docs',
+                "api-docs",
                 __name__,
                 url_prefix=_add_leading_slash(api_url),
-                template_folder='./templates',
+                template_folder="./templates",
             )
             # Serve json spec at 'url_prefix/openapi.json' by default
-            json_path = self._app.config.get(
-                'OPENAPI_JSON_PATH', 'openapi.json')
+            json_path = self._app.config.get("OPENAPI_JSON_PATH", "openapi.json")
             blueprint.add_url_rule(
                 _add_leading_slash(json_path),
-                endpoint='openapi_json',
-                view_func=self._openapi_json)
+                endpoint="openapi_json",
+                view_func=self._openapi_json,
+            )
             self._register_redoc_rule(blueprint)
             self._register_swagger_ui_rule(blueprint)
             self._register_rapidoc_rule(blueprint)
@@ -59,15 +60,16 @@ class DocBlueprintMixin:
 
         The ReDoc script URL should be specified as OPENAPI_REDOC_URL.
         """
-        redoc_path = self._app.config.get('OPENAPI_REDOC_PATH')
+        redoc_path = self._app.config.get("OPENAPI_REDOC_PATH")
         if redoc_path is not None:
-            redoc_url = self._app.config.get('OPENAPI_REDOC_URL')
+            redoc_url = self._app.config.get("OPENAPI_REDOC_URL")
             if redoc_url is not None:
                 self._redoc_url = redoc_url
                 blueprint.add_url_rule(
                     _add_leading_slash(redoc_path),
-                    endpoint='openapi_redoc',
-                    view_func=self._openapi_redoc)
+                    endpoint="openapi_redoc",
+                    view_func=self._openapi_redoc,
+                )
 
     def _register_swagger_ui_rule(self, blueprint):
         """Register Swagger UI rule
@@ -75,61 +77,63 @@ class DocBlueprintMixin:
         The Swagger UI scripts base URL should be specified as
         OPENAPI_SWAGGER_UI_URL.
         """
-        swagger_ui_path = self._app.config.get('OPENAPI_SWAGGER_UI_PATH')
+        swagger_ui_path = self._app.config.get("OPENAPI_SWAGGER_UI_PATH")
         if swagger_ui_path is not None:
-            swagger_ui_url = self._app.config.get('OPENAPI_SWAGGER_UI_URL')
+            swagger_ui_url = self._app.config.get("OPENAPI_SWAGGER_UI_URL")
             if swagger_ui_url is not None:
                 self._swagger_ui_url = swagger_ui_url
                 blueprint.add_url_rule(
                     _add_leading_slash(swagger_ui_path),
-                    endpoint='openapi_swagger_ui',
-                    view_func=self._openapi_swagger_ui)
+                    endpoint="openapi_swagger_ui",
+                    view_func=self._openapi_swagger_ui,
+                )
 
     def _register_rapidoc_rule(self, blueprint):
         """Register RapiDoc rule
 
         The RapiDoc script URL should be specified as OPENAPI_RAPIDOC_URL.
         """
-        rapidoc_path = self._app.config.get('OPENAPI_RAPIDOC_PATH')
+        rapidoc_path = self._app.config.get("OPENAPI_RAPIDOC_PATH")
         if rapidoc_path is not None:
-            rapidoc_url = self._app.config.get('OPENAPI_RAPIDOC_URL')
+            rapidoc_url = self._app.config.get("OPENAPI_RAPIDOC_URL")
             if rapidoc_url is not None:
                 self._rapidoc_url = rapidoc_url
                 blueprint.add_url_rule(
                     _add_leading_slash(rapidoc_path),
-                    endpoint='openapi_rapidoc',
-                    view_func=self._openapi_rapidoc)
+                    endpoint="openapi_rapidoc",
+                    view_func=self._openapi_rapidoc,
+                )
 
     def _openapi_json(self):
         """Serve JSON spec file"""
         # We don't use Flask.jsonify here as it would sort the keys
         # alphabetically while we want to preserve the order.
         return current_app.response_class(
-            json.dumps(self.spec.to_dict(), indent=2),
-            mimetype='application/json')
+            json.dumps(self.spec.to_dict(), indent=2), mimetype="application/json"
+        )
 
     def _openapi_redoc(self):
         """Expose OpenAPI spec with ReDoc"""
         return flask.render_template(
-            'redoc.html', title=self.spec.title, redoc_url=self._redoc_url)
+            "redoc.html", title=self.spec.title, redoc_url=self._redoc_url
+        )
 
     def _openapi_swagger_ui(self):
         """Expose OpenAPI spec with Swagger UI"""
         return flask.render_template(
-            'swagger_ui.html',
+            "swagger_ui.html",
             title=self.spec.title,
             swagger_ui_url=self._swagger_ui_url,
-            swagger_ui_config=self._app.config.get(
-                'OPENAPI_SWAGGER_UI_CONFIG', {})
+            swagger_ui_config=self._app.config.get("OPENAPI_SWAGGER_UI_CONFIG", {}),
         )
 
     def _openapi_rapidoc(self):
         """Expose OpenAPI spec with RapiDoc"""
         return flask.render_template(
-            'rapidoc.html',
+            "rapidoc.html",
             title=self.spec.title,
             rapidoc_url=self._rapidoc_url,
-            rapidoc_config=self._app.config.get('OPENAPI_RAPIDOC_CONFIG', {})
+            rapidoc_config=self._app.config.get("OPENAPI_RAPIDOC_CONFIG", {}),
         )
 
 
@@ -139,15 +143,15 @@ class APISpecMixin(DocBlueprintMixin):
     DEFAULT_ERROR_RESPONSE_NAME = "DEFAULT_ERROR"
 
     def _init_spec(
-            self,
-            *,
-            flask_plugin=None,
-            marshmallow_plugin=None,
-            extra_plugins=None,
-            title=None,
-            version=None,
-            openapi_version=None,
-            **options
+        self,
+        *,
+        flask_plugin=None,
+        marshmallow_plugin=None,
+        extra_plugins=None,
+        title=None,
+        version=None,
+        openapi_version=None,
+        **options
     ):
         # Plugins
         self.flask_plugin = flask_plugin or FlaskPlugin()
@@ -156,36 +160,47 @@ class APISpecMixin(DocBlueprintMixin):
         plugins.extend(extra_plugins or ())
 
         # APISpec options
-        title = self._app.config.get('API_TITLE', title)
+        title = self._app.config.get("API_TITLE", title)
         if title is None:
             raise MissingAPIParameterError(
                 'API title must be specified either as "API_TITLE" '
                 'app parameter or as "title" spec kwarg.'
             )
-        version = self._app.config.get('API_VERSION', version)
+        version = self._app.config.get("API_VERSION", version)
         if version is None:
             raise MissingAPIParameterError(
                 'API version must be specified either as "API_VERSION" '
                 'app parameter or as "version" spec kwarg.'
             )
-        openapi_version = self._app.config.get(
-            'OPENAPI_VERSION', openapi_version)
+        openapi_version = self._app.config.get("OPENAPI_VERSION", openapi_version)
         if openapi_version is None:
             raise MissingAPIParameterError(
                 'OpenAPI version must be specified either as "OPENAPI_VERSION '
                 'app parameter or as "openapi_version" spec kwarg.'
             )
-        openapi_major_version = int(openapi_version.split('.')[0])
+        openapi_major_version = int(openapi_version.split(".")[0])
         if openapi_major_version < 3:
             options.setdefault(
-                'produces', [DEFAULT_RESPONSE_CONTENT_TYPE, ])
+                "produces",
+                [
+                    DEFAULT_RESPONSE_CONTENT_TYPE,
+                ],
+            )
             options.setdefault(
-                'consumes', [DEFAULT_REQUEST_BODY_CONTENT_TYPE, ])
-        options.update(self._app.config.get('API_SPEC_OPTIONS', {}))
+                "consumes",
+                [
+                    DEFAULT_REQUEST_BODY_CONTENT_TYPE,
+                ],
+            )
+        options.update(self._app.config.get("API_SPEC_OPTIONS", {}))
 
         # Instantiate spec
         self.spec = apispec.APISpec(
-            title, version, openapi_version, plugins, **options,
+            title,
+            version,
+            openapi_version,
+            plugins,
+            **options,
         )
 
         # Register custom fields in spec
@@ -291,48 +306,50 @@ class APISpecMixin(DocBlueprintMixin):
         # Lazy register a response for each status code
         for status in http.HTTPStatus:
             response = {
-                'description': status.phrase,
-                'schema': self.ERROR_SCHEMA,
+                "description": status.phrase,
+                "schema": self.ERROR_SCHEMA,
             }
-            prepare_response(
-                response, self.spec, DEFAULT_RESPONSE_CONTENT_TYPE)
+            prepare_response(response, self.spec, DEFAULT_RESPONSE_CONTENT_TYPE)
             self.spec.components.response(status.name, response, lazy=True)
 
         # Also lazy register a default error response
         response = {
-            'description': 'Default error response',
-            'schema': self.ERROR_SCHEMA,
+            "description": "Default error response",
+            "schema": self.ERROR_SCHEMA,
         }
         prepare_response(response, self.spec, DEFAULT_RESPONSE_CONTENT_TYPE)
-        self.spec.components.response('DEFAULT_ERROR', response, lazy=True)
+        self.spec.components.response("DEFAULT_ERROR", response, lazy=True)
 
     def _register_etag_headers(self):
         self.spec.components.parameter(
-            "IF_NONE_MATCH", "header", fs_etag.IF_NONE_MATCH_HEADER, lazy=True)
+            "IF_NONE_MATCH", "header", fs_etag.IF_NONE_MATCH_HEADER, lazy=True
+        )
         self.spec.components.parameter(
-            "IF_MATCH", "header", fs_etag.IF_MATCH_HEADER, lazy=True)
+            "IF_MATCH", "header", fs_etag.IF_MATCH_HEADER, lazy=True
+        )
         if self.spec.openapi_version.major >= 3:
             self.spec.components.header("ETAG", fs_etag.ETAG_HEADER, lazy=True)
 
     def _register_pagination_header(self):
         if self.spec.openapi_version.major >= 3:
             self.spec.components.header(
-                "PAGINATION", fs_pagination.PAGINATION_HEADER, lazy=True)
+                "PAGINATION", fs_pagination.PAGINATION_HEADER, lazy=True
+            )
 
 
-openapi_cli = flask.cli.AppGroup('openapi', help='OpenAPI commands.')
+openapi_cli = flask.cli.AppGroup("openapi", help="OpenAPI commands.")
 
 
-@openapi_cli.command('print')
+@openapi_cli.command("print")
 def print_openapi_doc():
     """Print OpenAPI document."""
-    api = current_app.extensions['flask-smorest']['ext_obj']
+    api = current_app.extensions["flask-smorest"]["ext_obj"]
     click.echo(json.dumps(api.spec.to_dict(), indent=2))
 
 
-@openapi_cli.command('write')
-@click.argument('output_file', type=click.File(mode='w'))
+@openapi_cli.command("write")
+@click.argument("output_file", type=click.File(mode="w"))
 def write_openapi_doc(output_file):
     """Write OpenAPI document to a file."""
-    api = current_app.extensions['flask-smorest']['ext_obj']
+    api = current_app.extensions["flask-smorest"]["ext_obj"]
     click.echo(json.dumps(api.spec.to_dict(), indent=2), file=output_file)
