@@ -7,8 +7,8 @@ def uploadfield2properties(self, field, **kwargs):
     ret = {}
     if isinstance(field, Upload):
         if self.openapi_version.major < 3:
-            ret['type'] = 'file'
+            ret["type"] = "file"
         else:
-            ret['type'] = 'string'
-            ret['format'] = field.format
+            ret["type"] = "string"
+            ret["format"] = field.format
     return ret
