@@ -15,23 +15,27 @@ from .utils import get_responses, get_headers, get_parameters, build_ref
 class TestAPISpec:
     """Test APISpec class"""
 
-    @pytest.mark.parametrize('openapi_version', ['2.0', '3.0.2'])
+    @pytest.mark.parametrize("openapi_version", ["2.0", "3.0.2"])
     def test_apispec_sets_produces_consumes(self, app, openapi_version):
-        app.config['OPENAPI_VERSION'] = openapi_version
+        app.config["OPENAPI_VERSION"] = openapi_version
         api = Api(app)
         spec = api.spec.to_dict()
 
-        if openapi_version == '2.0':
-            assert spec['produces'] == ['application/json', ]
-            assert spec['consumes'] == ['application/json', ]
+        if openapi_version == "2.0":
+            assert spec["produces"] == [
+                "application/json",
+            ]
+            assert spec["consumes"] == [
+                "application/json",
+            ]
         else:
-            assert 'produces' not in spec
-            assert 'consumes' not in spec
+            assert "produces" not in spec
+            assert "consumes" not in spec
 
-    @pytest.mark.parametrize('openapi_version', ['2.0', '3.0.2'])
+    @pytest.mark.parametrize("openapi_version", ["2.0", "3.0.2"])
     def test_api_lazy_registers_error_responses(self, app, openapi_version):
         """Test error responses are registered"""
-        app.config['OPENAPI_VERSION'] = openapi_version
+        app.config["OPENAPI_VERSION"] = openapi_version
         api = Api(app)
 
         # Declare a dummy response to ensure get_response doesn't fail
@@ -44,7 +48,7 @@ class TestAPISpec:
             assert status.name not in responses
 
         # Register routes with all error responses
-        blp = Blueprint('test', 'test', url_prefix='/test')
+        blp = Blueprint("test", "test", url_prefix="/test")
 
         for status in http.HTTPStatus:
 
@@ -57,25 +61,25 @@ class TestAPISpec:
 
         # Errors are now registered
         for status in http.HTTPStatus:
-            if openapi_version == '2.0':
+            if openapi_version == "2.0":
                 assert responses[status.name] == {
-                    'description': status.phrase,
-                    'schema': build_ref(api.spec, 'schema', 'Error'),
+                    "description": status.phrase,
+                    "schema": build_ref(api.spec, "schema", "Error"),
                 }
             else:
                 assert responses[status.name] == {
-                    'description': status.phrase,
-                    'content': {
-                        'application/json': {
-                            'schema': build_ref(api.spec, 'schema', 'Error')
+                    "description": status.phrase,
+                    "content": {
+                        "application/json": {
+                            "schema": build_ref(api.spec, "schema", "Error")
                         }
-                    }
+                    },
                 }
 
-    @pytest.mark.parametrize('openapi_version', ['2.0', '3.0.2'])
+    @pytest.mark.parametrize("openapi_version", ["2.0", "3.0.2"])
     def test_api_lazy_registers_etag_headers(self, app, openapi_version):
         """Test etag headers are registered"""
-        app.config['OPENAPI_VERSION'] = openapi_version
+        app.config["OPENAPI_VERSION"] = openapi_version
         api = Api(app)
 
         # Declare dummy components to ensure get_* don't fail
@@ -91,15 +95,11 @@ class TestAPISpec:
             assert headers == {"Header_1": header_1}
         parameters = get_parameters(api.spec)
         assert parameters == {
-            "Parameter_1": {
-                **parameter_1,
-                "in": "header",
-                "name": "Parameter_1"
-            }
+            "Parameter_1": {**parameter_1, "in": "header", "name": "Parameter_1"}
         }
 
         # Register routes with etag
-        blp = Blueprint('test', 'test', url_prefix='/test')
+        blp = Blueprint("test", "test", url_prefix="/test")
 
         @blp.route("/etag_get", methods=["GET"])
         @blp.etag
@@ -135,7 +135,7 @@ class TestAPISpec:
         assert headers == {"Header_1": header_1}
 
         # Register routes with pagination
-        blp = Blueprint('test', 'test', url_prefix='/test')
+        blp = Blueprint("test", "test", url_prefix="/test")
 
         @blp.route("/")
         @blp.response(200)
@@ -147,21 +147,21 @@ class TestAPISpec:
 
         headers = get_headers(api.spec)
         assert headers["PAGINATION"] == {
-            'description': 'Pagination metadata',
-            'schema': {'$ref': '#/components/schemas/PaginationMetadata'},
+            "description": "Pagination metadata",
+            "schema": {"$ref": "#/components/schemas/PaginationMetadata"},
         }
 
     def test_apispec_print_openapi_doc(self, app):
         api = Api(app)
-        result = app.test_cli_runner().invoke(args=('openapi', 'print'))
+        result = app.test_cli_runner().invoke(args=("openapi", "print"))
         assert result.exit_code == 0
         assert json.loads(result.output) == api.spec.to_dict()
 
     def test_apispec_write_openapi_doc(self, app, tmp_path):
-        output_file = tmp_path / 'openapi.json'
+        output_file = tmp_path / "openapi.json"
         api = Api(app)
         result = app.test_cli_runner().invoke(
-            args=('openapi', 'write', str(output_file))
+            args=("openapi", "write", str(output_file))
         )
         assert result.exit_code == 0
         with open(output_file) as output:
@@ -172,17 +172,18 @@ class TestAPISpecServeDocs:
     """Test APISpec class doc-serving features"""
 
     @pytest.mark.parametrize(
-        'prefix',
+        "prefix",
         (
             None,
-            'docs_url_prefix',
-            '/docs_url_prefix',
-            'docs_url_prefix/',
-            '/docs_url_prefix/'
-        )
+            "docs_url_prefix",
+            "/docs_url_prefix",
+            "docs_url_prefix/",
+            "/docs_url_prefix/",
+        ),
     )
     def test_apispec_serve_spec_prefix(self, app, prefix):
         """Test url prefix default value and leading/trailing slashes issues"""
+
         class NewAppConfig(AppConfig):
             if prefix is not None:
                 OPENAPI_URL_PREFIX = prefix
@@ -190,15 +191,14 @@ class TestAPISpecServeDocs:
         app.config.from_object(NewAppConfig)
         Api(app)
         client = app.test_client()
-        resp_json_docs = client.get('/docs_url_prefix/openapi.json')
-        if app.config.get('OPENAPI_URL_PREFIX') is None:
+        resp_json_docs = client.get("/docs_url_prefix/openapi.json")
+        if app.config.get("OPENAPI_URL_PREFIX") is None:
             assert resp_json_docs.status_code == 404
         else:
-            assert resp_json_docs.json['info'] == {
-                'version': '1', 'title': 'API Test'}
+            assert resp_json_docs.json["info"] == {"version": "1", "title": "API Test"}
 
-    @pytest.mark.parametrize('prefix', (None, 'docs_url_prefix'))
-    @pytest.mark.parametrize('json_path', (None, 'spec.json'))
+    @pytest.mark.parametrize("prefix", (None, "docs_url_prefix"))
+    @pytest.mark.parametrize("json_path", (None, "spec.json"))
     def test_apispec_serve_spec_json_path(self, app, prefix, json_path):
         class NewAppConfig(AppConfig):
             if prefix is not None:
@@ -209,29 +209,27 @@ class TestAPISpecServeDocs:
         app.config.from_object(NewAppConfig)
         Api(app)
         client = app.test_client()
-        resp_json_docs_default = client.get('/docs_url_prefix/openapi.json')
-        resp_json_docs_custom = client.get('/docs_url_prefix/spec.json')
-        if app.config.get('OPENAPI_URL_PREFIX') is None:
+        resp_json_docs_default = client.get("/docs_url_prefix/openapi.json")
+        resp_json_docs_custom = client.get("/docs_url_prefix/spec.json")
+        if app.config.get("OPENAPI_URL_PREFIX") is None:
             assert resp_json_docs_default.status_code == 404
             assert resp_json_docs_custom.status_code == 404
         else:
             if json_path is None:
-                assert resp_json_docs_default.json['info'] == (
-                    {'version': '1', 'title': 'API Test'}
+                assert resp_json_docs_default.json["info"] == (
+                    {"version": "1", "title": "API Test"}
                 )
                 assert resp_json_docs_custom.status_code == 404
             else:
-                assert resp_json_docs_custom.json['info'] == (
-                    {'version': '1', 'title': 'API Test'}
+                assert resp_json_docs_custom.json["info"] == (
+                    {"version": "1", "title": "API Test"}
                 )
                 assert resp_json_docs_default.status_code == 404
 
-    @pytest.mark.parametrize('prefix', (None, 'docs_url_prefix'))
-    @pytest.mark.parametrize('redoc_path', (None, 'redoc'))
-    @pytest.mark.parametrize('redoc_url', (None, 'https://my-redoc/'))
-    def test_apispec_serve_spec_redoc(
-            self, app, prefix, redoc_path, redoc_url
-    ):
+    @pytest.mark.parametrize("prefix", (None, "docs_url_prefix"))
+    @pytest.mark.parametrize("redoc_path", (None, "redoc"))
+    @pytest.mark.parametrize("redoc_url", (None, "https://my-redoc/"))
+    def test_apispec_serve_spec_redoc(self, app, prefix, redoc_path, redoc_url):
         class NewAppConfig(AppConfig):
             if prefix is not None:
                 OPENAPI_URL_PREFIX = prefix
@@ -240,30 +238,31 @@ class TestAPISpecServeDocs:
             if redoc_url is not None:
                 OPENAPI_REDOC_URL = redoc_url
 
-        title_tag = '<title>API Test</title>'
+        title_tag = "<title>API Test</title>"
         app.config.from_object(NewAppConfig)
         Api(app)
         client = app.test_client()
-        response_redoc = client.get('/docs_url_prefix/redoc')
-        if app.config.get('OPENAPI_URL_PREFIX') is None:
+        response_redoc = client.get("/docs_url_prefix/redoc")
+        if app.config.get("OPENAPI_URL_PREFIX") is None:
             assert response_redoc.status_code == 404
         else:
             if (
-                    app.config.get('OPENAPI_REDOC_PATH') is None or
-                    app.config.get('OPENAPI_REDOC_URL') is None
+                app.config.get("OPENAPI_REDOC_PATH") is None
+                or app.config.get("OPENAPI_REDOC_URL") is None
             ):
                 assert response_redoc.status_code == 404
             else:
                 assert response_redoc.status_code == 200
-                assert (response_redoc.headers['Content-Type'] ==
-                        'text/html; charset=utf-8')
+                assert (
+                    response_redoc.headers["Content-Type"] == "text/html; charset=utf-8"
+                )
                 assert title_tag in response_redoc.get_data(True)
 
-    @pytest.mark.parametrize('prefix', (None, 'docs_url_prefix'))
-    @pytest.mark.parametrize('swagger_ui_path', (None, 'swagger-ui'))
-    @pytest.mark.parametrize('swagger_ui_url', (None, 'https://my-swagger/'))
+    @pytest.mark.parametrize("prefix", (None, "docs_url_prefix"))
+    @pytest.mark.parametrize("swagger_ui_path", (None, "swagger-ui"))
+    @pytest.mark.parametrize("swagger_ui_url", (None, "https://my-swagger/"))
     def test_apispec_serve_spec_swagger_ui(
-            self, app, prefix, swagger_ui_path, swagger_ui_url
+        self, app, prefix, swagger_ui_path, swagger_ui_url
     ):
         class NewAppConfig(AppConfig):
             if prefix is not None:
@@ -273,23 +272,25 @@ class TestAPISpecServeDocs:
             if swagger_ui_url is not None:
                 OPENAPI_SWAGGER_UI_URL = swagger_ui_url
 
-        title_tag = '<title>API Test</title>'
+        title_tag = "<title>API Test</title>"
         app.config.from_object(NewAppConfig)
         Api(app)
         client = app.test_client()
-        response_swagger_ui = client.get('/docs_url_prefix/swagger-ui')
-        if app.config.get('OPENAPI_URL_PREFIX') is None:
+        response_swagger_ui = client.get("/docs_url_prefix/swagger-ui")
+        if app.config.get("OPENAPI_URL_PREFIX") is None:
             assert response_swagger_ui.status_code == 404
         else:
             if (
-                    app.config.get('OPENAPI_SWAGGER_UI_PATH') is None or
-                    app.config.get('OPENAPI_SWAGGER_UI_URL') is None
+                app.config.get("OPENAPI_SWAGGER_UI_PATH") is None
+                or app.config.get("OPENAPI_SWAGGER_UI_URL") is None
             ):
                 assert response_swagger_ui.status_code == 404
             else:
                 assert response_swagger_ui.status_code == 200
-                assert (response_swagger_ui.headers['Content-Type'] ==
-                        'text/html; charset=utf-8')
+                assert (
+                    response_swagger_ui.headers["Content-Type"]
+                    == "text/html; charset=utf-8"
+                )
                 assert title_tag in response_swagger_ui.get_data(True)
 
     def test_apispec_serve_spec_swagger_ui_config(self, app):
@@ -306,17 +307,15 @@ class TestAPISpecServeDocs:
         client = app.test_client()
         response_swagger_ui = client.get("/")
         assert (
-            'var override_config = {'
+            "var override_config = {"
             '"supportedSubmitMethods": ["get", "put", "post", "delete"]'
-            '};'
+            "};"
         ) in response_swagger_ui.get_data(True)
 
-    @pytest.mark.parametrize('prefix', (None, 'docs_url_prefix'))
-    @pytest.mark.parametrize('rapidoc_path', (None, 'rapidoc'))
-    @pytest.mark.parametrize('rapidoc_url', (None, 'https://my-rapidoc/'))
-    def test_apispec_serve_spec_rapidoc(
-            self, app, prefix, rapidoc_path, rapidoc_url
-    ):
+    @pytest.mark.parametrize("prefix", (None, "docs_url_prefix"))
+    @pytest.mark.parametrize("rapidoc_path", (None, "rapidoc"))
+    @pytest.mark.parametrize("rapidoc_url", (None, "https://my-rapidoc/"))
+    def test_apispec_serve_spec_rapidoc(self, app, prefix, rapidoc_path, rapidoc_url):
         class NewAppConfig(AppConfig):
             if prefix is not None:
                 OPENAPI_URL_PREFIX = prefix
@@ -325,23 +324,25 @@ class TestAPISpecServeDocs:
             if rapidoc_url is not None:
                 OPENAPI_RAPIDOC_URL = rapidoc_url
 
-        title_tag = '<title>API Test</title>'
+        title_tag = "<title>API Test</title>"
         app.config.from_object(NewAppConfig)
         Api(app)
         client = app.test_client()
-        response_rapidoc = client.get('/docs_url_prefix/rapidoc')
-        if app.config.get('OPENAPI_URL_PREFIX') is None:
+        response_rapidoc = client.get("/docs_url_prefix/rapidoc")
+        if app.config.get("OPENAPI_URL_PREFIX") is None:
             assert response_rapidoc.status_code == 404
         else:
             if (
-                    app.config.get('OPENAPI_RAPIDOC_PATH') is None or
-                    app.config.get('OPENAPI_RAPIDOC_URL') is None
+                app.config.get("OPENAPI_RAPIDOC_PATH") is None
+                or app.config.get("OPENAPI_RAPIDOC_URL") is None
             ):
                 assert response_rapidoc.status_code == 404
             else:
                 assert response_rapidoc.status_code == 200
-                assert (response_rapidoc.headers['Content-Type'] ==
-                        'text/html; charset=utf-8')
+                assert (
+                    response_rapidoc.headers["Content-Type"]
+                    == "text/html; charset=utf-8"
+                )
                 assert title_tag in response_rapidoc.get_data(True)
 
     def test_apispec_serve_spec_rapidoc_config(self, app):
@@ -357,12 +358,9 @@ class TestAPISpecServeDocs:
         response_rapidoc = client.get("/")
         assert 'theme = "dark"' in response_rapidoc.get_data(True)
 
-    @pytest.mark.parametrize('prefix', ('', '/'))
-    @pytest.mark.parametrize('path', ('', '/'))
-    @pytest.mark.parametrize(
-        'tested',
-        ('json', 'redoc', 'swagger-ui', 'rapidoc')
-    )
+    @pytest.mark.parametrize("prefix", ("", "/"))
+    @pytest.mark.parametrize("path", ("", "/"))
+    @pytest.mark.parametrize("tested", ("json", "redoc", "swagger-ui", "rapidoc"))
     def test_apispec_serve_spec_empty_path(self, app, prefix, path, tested):
         """Test empty string or (equivalently) single slash as paths
 
@@ -376,37 +374,36 @@ class TestAPISpecServeDocs:
             OPENAPI_RAPIDOC_URL = "https://domain.tld/rapidoc"
 
         mapping = {
-            'json': 'OPENAPI_JSON_PATH',
-            'redoc': 'OPENAPI_REDOC_PATH',
-            'swagger-ui': 'OPENAPI_SWAGGER_UI_PATH',
-            'rapidoc': 'OPENAPI_RAPIDOC_PATH',
+            "json": "OPENAPI_JSON_PATH",
+            "redoc": "OPENAPI_REDOC_PATH",
+            "swagger-ui": "OPENAPI_SWAGGER_UI_PATH",
+            "rapidoc": "OPENAPI_RAPIDOC_PATH",
         }
         setattr(NewAppConfig, mapping[tested], path)
 
         app.config.from_object(NewAppConfig)
         Api(app)
         client = app.test_client()
-        if tested == 'json':
-            response_json_docs = client.get('/')
+        if tested == "json":
+            response_json_docs = client.get("/")
         else:
-            response_json_docs = client.get('openapi.json')
-            response_doc_page = client.get('/')
+            response_json_docs = client.get("openapi.json")
+            response_doc_page = client.get("/")
             assert response_doc_page.status_code == 200
-            assert (response_doc_page.headers['Content-Type'] ==
-                    'text/html; charset=utf-8')
-        assert response_json_docs.json['info'] == {
-            'version': '1', 'title': 'API Test'}
+            assert (
+                response_doc_page.headers["Content-Type"] == "text/html; charset=utf-8"
+            )
+        assert response_json_docs.json["info"] == {"version": "1", "title": "API Test"}
 
     def test_apispec_serve_spec_preserve_order(self, app):
-        app.config['OPENAPI_URL_PREFIX'] = '/api-docs'
+        app.config["OPENAPI_URL_PREFIX"] = "/api-docs"
         api = Api(app)
         client = app.test_client()
 
         # Add ordered stuff. This is invalid, but it will do for the test.
-        paths = OrderedDict(
-            [('/path_{}'.format(i), str(i)) for i in range(20)])
+        paths = OrderedDict([(f"/path_{i}", str(i)) for i in range(20)])
         api.spec._paths = paths
 
-        response_json_docs = client.get('/api-docs/openapi.json')
+        response_json_docs = client.get("/api-docs/openapi.json")
         assert response_json_docs.status_code == 200
-        assert response_json_docs.json['paths'] == paths
+        assert response_json_docs.json["paths"] == paths
